@@ -433,7 +433,7 @@ create_error_tile (ChamplainTile* tile)
     }
 
   clone = clutter_clone_new (error_actor);
-  champlain_tile_set_content (tile, clone, TRUE);
+  champlain_tile_set_content (tile, clone, FALSE);
   champlain_tile_set_state (tile, CHAMPLAIN_STATE_DONE);
 }
 
@@ -578,7 +578,7 @@ file_loaded_cb (SoupSession *session,
         }
     }
 
-  champlain_tile_set_content (tile, actor, TRUE);
+  champlain_tile_set_content (tile, actor, FALSE);
   DEBUG ("Tile loaded from network");
 
 cleanup:
